@@ -292,13 +292,17 @@ def _log_hosts(instances):
 def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installPath='.', node=''):
 
 
-    # ensure yarn installs all build tools
+ # Need to give each build job it's own yarn cache, as the yarn cache is not safe for concurrent builds.
+ # For more info: https://github.com/yarnpkg/yarn/issues/683#issuecomment-346038525
     yarn_cache=os.getenv('PWD','') + '/.yarn_cache/'
     local('mkdir -p .yarn_cache/')
     local('yarn config set cache-folder %s' % yarn_cache)
+
     with lcd(installPath):
+
+    # ensure yarn installs all build tools
         local("pwd")
-        local('yarn --production=false --no-progress --non-interactive --cache-folder install')
+        local('yarn --production=false --no-progress --non-interactive install')
 
  
         if ngBuild:
@@ -403,7 +407,7 @@ def unpack_code():
 
 
 @task
-def link_new_code():
+def link_new_code(numKeep='5'):
     try:
         sudo('unlink /data/deploy/pending')
     except:
@@ -420,7 +424,7 @@ def link_new_code():
         #  6. keep only directory names that are *not* repeated - so this will be all directories beyond those first 5 numeric directories.
         #  7. filter out any alpha directories that were added by the second ls.
         #  8. remove all of the directories that remain.
-        sudo('(ls -t|grep 20|head -n 5;ls)|sort|uniq -u|grep 20|xargs rm -rf')
+        sudo('(ls -t|grep 20|head -n %s;ls)|sort|uniq -u|grep 20|xargs rm -rf' % numKeep)
 
 
 @task
@@ -464,9 +468,9 @@ def django_check():
 
 
 @task
-def remote_inflate_code():
+def remote_inflate_code(numKeep='5'):
     unpack_code()
-    link_new_code()
+    link_new_code(numKeep)
     codeversioner()
 
 
@@ -486,9 +490,9 @@ def codeversioner():
 # This assumes the local repo is ready (any build has been done and
 # commited), then creates the tarball, finally deploys one at a time
 @task
-def deploycode(branch, nltkLoad="False", doCollectStatic="True", djangoAdmin="True", yarn="False", immutable="True"):
+def deploycode(branch, nltkLoad="False", doCollectStatic="True", djangoAdmin="True", yarn="False", immutable="True", numKeep="5"):
     tar_from_git(branch)
-    remote_inflate_code()
+    remote_inflate_code(numKeep)
 
     if not yarn in TRUTH_VALUES:
         pip_install()
@@ -514,8 +518,8 @@ def deploycode(branch, nltkLoad="False", doCollectStatic="True", djangoAdmin="Tr
 # done prior), then deploys all targets in parallel
 @task
 @parallel
-def deployParallel(nltkLoad="False", doCollectStatic="True", djangoAdmin="True", yarn="False", immutable="True"):
-    remote_inflate_code()
+def deployParallel(nltkLoad="False", doCollectStatic="True", djangoAdmin="True", yarn="False", immutable="True", numKeep="5"):
+    remote_inflate_code(numKeep)
 
     if not yarn in TRUTH_VALUES:
         pip_install()
